containertools.get_first_element_starting_strictly_after_offset
===============================================================

.. autofunction:: abjad.tools.containertools.get_first_element_starting_strictly_after_offset.get_first_element_starting_strictly_after_offset
